@@ -21,7 +21,7 @@
 #ifndef C64CPU_H
 #define C64CPU_H
 
-#include "sidplayfp/c64/c64env.h"
+#include "c64/c64env.h"
 #include "CPU/mos6510.h"
 
 #ifdef HAVE_CONFIG_H
