@@ -1,7 +1,7 @@
 /*
  * This file is part of libsidplayfp, a SID player engine.
  *
- * Copyright 2013 Leandro Nini <drfiemost@users.sourceforge.net>
+ * Copyright 2013-2014 Leandro Nini <drfiemost@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,14 +21,15 @@
 #ifndef C64SID_H
 #define C64SID_H
 
-#include <stdint.h>
-
+#include "component.h"
 #include "Banks/Bank.h"
 
+#include <stdint.h>
+
 /**
-* SID interface.
-*/
-class c64sid : public Bank
+ * SID interface.
+ */
+class c64sid : public Bank, public component
 {
 protected:
     virtual ~c64sid() {}
@@ -36,8 +37,11 @@ protected:
 public:
     virtual void reset(uint8_t volume) = 0;
 
-    virtual void poke(uint_least16_t address, uint8_t value) = 0;
-    virtual uint8_t peek(uint_least16_t address) = 0;
+    void reset() { reset(0); }
+
+    // Bank functions
+    void poke(uint_least16_t address, uint8_t value) { write(address & 0x1f, value); }
+    uint8_t peek(uint_least16_t address) { return read(address & 0x1f); }
 };
 
 #endif // C64SID_H
