@@ -179,7 +179,7 @@ uint_least32_t Player::play(short *buffer, uint_least32_t count)
 
     if (m_mixer.getSid(0))
     {
-        if (count)
+        if (count && buffer)
         {
             while (m_isPlaying && m_mixer.notFinished())
             {
