@@ -27,23 +27,24 @@
 #  include "config.h"
 #endif
 
-class SidTuneTools
+namespace SidTuneTools
 {
- public:
-    /** Return pointer to file name position in complete path. */
-    static size_t fileNameWithoutPath(const char* s);
+    /**
+     * Return pointer to file name position in complete path.
+     */
+    size_t fileNameWithoutPath(const char* s);
 
     /**
-    * Return pointer to file name position in complete path.
-    * Special version: file separator = forward slash.
-    */
-    static size_t slashedFileNameWithoutPath(const char* s);
+     * Return pointer to file name position in complete path.
+     * Special version: file separator = forward slash.
+     */
+    size_t slashedFileNameWithoutPath(const char* s);
 
     /**
-    * Return pointer to file name extension in path.
-    * Searching backwards until first dot is found.
-    */
-    static const char* fileExtOfPath(const char* s);
-};
+     * Return pointer to file name extension in path.
+     * Searching backwards until first dot is found.
+     */
+    const char* fileExtOfPath(const char* s);
+}
 
 #endif  /* SIDTUNETOOLS_H */
